==> haskell-text-manipulate-0.3.1.0-120-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-manipulate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-manipulate
version:              0.3.1.0
visibility:           public
id:                   text-manipulate-0.3.1.0-BONAstaZoY8AaApsNwxOSa
key:                  text-manipulate-0.3.1.0-BONAstaZoY8AaApsNwxOSa
license:              MPL-2.0
copyright:            Copyright (c) 2014-2022 Brendan Hay
maintainer:           Brendan Hay <brendan.g.hay@gmail.com>
author:               Brendan Hay
homepage:             https://github.com/brendanhay/text-manipulate
synopsis:
    Case conversion, word boundary manipulation, and textual subjugation.

description:
    Manipulate identifiers and structurally non-complex pieces
    of text by delimiting word boundaries via a combination of whitespace,
    control-characters, and case-sensitivity.

    Has support for common idioms like casing of programmatic variable names,
    taking, dropping, and splitting by word, and modifying the first character
    of a piece of text.

category:             Data, Text
abi:                  623408795e4384222b26cedf3638f404
exposed:              True
exposed-modules:      Data.Text.Lazy.Manipulate Data.Text.Manipulate
hidden-modules:
    Data.Text.Manipulate.Internal.Fusion
    Data.Text.Manipulate.Internal.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-manipulate-0.3.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-manipulate-0.3.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-manipulate-0.3.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-manipulate
hs-libraries:         HStext-manipulate-0.3.1.0-BONAstaZoY8AaApsNwxOSa
depends:              base-4.17.2.1 text-2.0.2
haddock-interfaces:
    /usr/share/doc/haskell-text-manipulate/html/text-manipulate.haddock

haddock-html:         /usr/share/doc/haskell-text-manipulate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-manipulate-0.3.1.0-121-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-manipulate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-manipulate
version:              0.3.1.0
visibility:           public
id:                   text-manipulate-0.3.1.0-LXn4aiaYq87oI9CFEgR5M
key:                  text-manipulate-0.3.1.0-LXn4aiaYq87oI9CFEgR5M
license:              MPL-2.0
copyright:            Copyright (c) 2014-2022 Brendan Hay
maintainer:           Brendan Hay <brendan.g.hay@gmail.com>
author:               Brendan Hay
homepage:             https://github.com/brendanhay/text-manipulate
synopsis:
    Case conversion, word boundary manipulation, and textual subjugation.

description:
    Manipulate identifiers and structurally non-complex pieces
    of text by delimiting word boundaries via a combination of whitespace,
    control-characters, and case-sensitivity.

    Has support for common idioms like casing of programmatic variable names,
    taking, dropping, and splitting by word, and modifying the first character
    of a piece of text.

category:             Data, Text
abi:                  e4de12ac4ed39e4f4a27e6c32d8a532e
exposed:              True
exposed-modules:      Data.Text.Lazy.Manipulate Data.Text.Manipulate
hidden-modules:
    Data.Text.Manipulate.Internal.Fusion
    Data.Text.Manipulate.Internal.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-manipulate-0.3.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-manipulate-0.3.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-manipulate-0.3.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-manipulate
hs-libraries:         HStext-manipulate-0.3.1.0-LXn4aiaYq87oI9CFEgR5M
depends:              base-4.17.2.1 text-2.0.2
haddock-interfaces:
    /usr/share/doc/haskell-text-manipulate/html/text-manipulate.haddock

haddock-html:         /usr/share/doc/haskell-text-manipulate/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
